@@ -29,7 +29,7 @@ end
 
 class OnlineSshPushTest < Rugged::OnlineTestCase
   def setup
-    skip unless Rugged.features.include?(:ssh)
+    skip unless Rugged.features.include?(:ssh) && git_creds?
 
     @repo = FixtureRepo.from_libgit2("push_src")
     @remote = @repo.remotes.create("test", ENV['GITTEST_REMOTE_SSH_URL'])
@@ -45,7 +45,7 @@ class OnlineSshPushTest < Rugged::OnlineTestCase
                    "refs/heads/b3:refs/heads/b3",
                    "refs/heads/b4:refs/heads/b4",
                    "refs/heads/b5:refs/heads/b5"
-                 ], {
+                 ], **{
                    credentials: ssh_key_credential
                  })
 
